@@ -5,5 +5,5 @@ from qr_code import views
 
 app_name = 'qr_code'
 urlpatterns = [
-    path('images/serve_qr_code_image/', views.serve_qr_code_image, name='serve_qr_code_image')
+    path('images/serve-qr-code-image/', views.serve_qr_code_image, name='serve_qr_code_image')
 ]
